﻿using System.Linq;
using Rhino.FileIO;
using Rhino.Geometry;
using Xunit;

namespace KnownFailures
{
    [Collection("RhinoTestingCollection")]

    public class Meshing
    {
        [MemberData(nameof(TestData))]
        [Theory]
        public void QuadRemesh(Vector3d offset, double targetEdgeLength)
        {
            var center = new Point3d(48.799839823176981, 121.7702136798768, -2.2204460492503131E-16) + offset;

            var file = File3dm.Read("HalfConeCustom.3dm");
            var cone = file.Objects.Where(obj => obj.Geometry is Brep).Select(obj => obj.Geometry as Brep).First();

            var bb = cone.GetBoundingBox(false);
            var delta = center - bb.Center;
            Assert.True(cone.Translate(delta));

            // Generate a mesh from the workpiece so we can color its vertices 
            var quadRemeshParams = new Rhino.Geometry.QuadRemeshParameters
            {
                // Note This is a meshing parameter: note we may want this to be more explicitly settable at some point, because it would inform the
                // density/detail of the heatmap
                TargetEdgeLength = targetEdgeLength
            };

            Assert.NotNull(Rhino.Geometry.Mesh.QuadRemeshBrep(cone, quadRemeshParams));
        }

        public static TheoryData<Vector3d, double> TestData = new TheoryData<Vector3d, double>()
        {
            { Vector3d.Zero, 0.2 },
            { Vector3d.Zero, 0.3 },
            { 0.001 * Vector3d.XAxis, 0.2 },
            { 0.001 * Vector3d.YAxis, 0.2 },
            { 0.001 * Vector3d.ZAxis, 0.2 },
            { 0.001 * Vector3d.XAxis, 0.3 },
            { 0.001 * Vector3d.YAxis, 0.3 },
            { 0.001 * Vector3d.ZAxis, 0.3 },
        };
    }
}
